@@ -17,6 +17,27 @@
  * along with QtRaw.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/*
+ * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
+ *
+ * Author:     LiuMingHang <liuminghang@uniontech.com>
+ *
+ * Maintainer: ZhangYong <ZhangYong@uniontech.com>
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "datastream.h"
 #include "rawiohandler.h"
 
@@ -29,9 +50,9 @@
 class RawIOHandlerPrivate
 {
 public:
-    RawIOHandlerPrivate(RawIOHandler *qq):
-        raw(0),
-        stream(0),
+    explicit RawIOHandlerPrivate(RawIOHandler *qq):
+        raw(nullptr),
+        stream(nullptr),
         q(qq)
     {}
 
@@ -49,26 +70,26 @@ public:
 RawIOHandlerPrivate::~RawIOHandlerPrivate()
 {
     delete raw;
-    raw = 0;
+    raw = nullptr;
     delete stream;
-    stream = 0;
+    stream = nullptr;
 }
 
 bool RawIOHandlerPrivate::load(QIODevice *device)
 {
-    if (device == 0) return false;
+    if (device == nullptr) return false;
 
     device->seek(0);
-    if (raw != 0) return true;
+    if (raw != nullptr) return true;
 
     stream = new Datastream(device);
     raw = new LibRaw;
     raw->imgdata.params.use_rawspeed = 1;
     if (raw->open_datastream(stream) != LIBRAW_SUCCESS) {
         delete raw;
-        raw = 0;
+        raw = nullptr;
         delete stream;
-        stream = 0;
+        stream = nullptr;
         return false;
     }
 
@@ -119,12 +140,12 @@ bool RawIOHandler::read(QImage *image)
     if (!d->load(device())) return false;
 
     QSize finalSize = d->scaledSize.isValid() ?
-        d->scaledSize : d->defaultSize;
+                      d->scaledSize : d->defaultSize;
 
     const libraw_data_t &imgdata = d->raw->imgdata;
     libraw_processed_image_t *output;
     if (finalSize.width() < imgdata.thumbnail.twidth ||
-        finalSize.height() < imgdata.thumbnail.theight) {
+            finalSize.height() < imgdata.thumbnail.theight) {
         qDebug() << "Using thumbnail";
         d->raw->unpack_thumb();
         output = d->raw->dcraw_make_mem_thumb();
@@ -136,9 +157,9 @@ bool RawIOHandler::read(QImage *image)
     }
 
     QImage unscaled;
-    uchar *pixels = 0;
+    uchar *pixels = nullptr;
     if (output->type == LIBRAW_IMAGE_JPEG) {
-        unscaled.loadFromData(output->data, output->data_size, "JPEG");
+        unscaled.loadFromData(output->data, static_cast<int>(output->data_size), "JPEG");
         if (imgdata.sizes.flip != 0) {
             QTransform rotation;
             int angle = 0;
@@ -170,8 +191,8 @@ bool RawIOHandler::read(QImage *image)
         unscaled = QImage(pixels,
                           output->width, output->height,
                           QImage::Format_RGB32)
-                // QImage::Format_RGB32 will cause window transparent, DON'T know why
-                .convertToFormat(QImage::Format_ARGB32);
+                   // QImage::Format_RGB32 will cause window transparent, DON'T know why
+                   .convertToFormat(QImage::Format_ARGB32);
     }
 
     if (unscaled.size() != finalSize) {
@@ -195,7 +216,7 @@ bool RawIOHandler::read(QImage *image)
 
 QVariant RawIOHandler::option(ImageOption option) const
 {
-    switch(option) {
+    switch (option) {
     case ImageFormat:
         return QImage::Format_RGB32;
     case Size:
@@ -210,9 +231,9 @@ QVariant RawIOHandler::option(ImageOption option) const
 }
 
 
-void RawIOHandler::setOption(ImageOption option, const QVariant & value)
+void RawIOHandler::setOption(ImageOption option, const QVariant &value)
 {
-    switch(option) {
+    switch (option) {
     case ScaledSize:
         d->scaledSize = value.toSize();
         break;
@@ -224,8 +245,7 @@ void RawIOHandler::setOption(ImageOption option, const QVariant & value)
 
 bool RawIOHandler::supportsOption(ImageOption option) const
 {
-    switch (option)
-    {
+    switch (option) {
     case ImageFormat:
     case Size:
     case ScaledSize:
